"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var rest_1 = __importDefault(require("@octokit/rest"));
var helpTopic_1 = require("../helpTopic");
var types_1 = require("./types");
var GitHubCommand = /** @class */ (function (_super) {
    __extends(GitHubCommand, _super);
    function GitHubCommand(authToken) {
        var _this = _super.call(this) || this;
        _this.name = 'github';
        _this.description = 'shows GitHub profile information';
        _this.subCommands = {};
        _this.octokit = new rest_1.default();
        _this.octokit.authenticate({ type: 'token', token: authToken });
        _this.helpTopic = new helpTopic_1.HelpTopic(_this, {
            synopsis: 'github'
        });
        _this.subCommands['repos'] = new GitHubReposSubCommand(_this.octokit);
        return _this;
    }
    GitHubCommand.prototype.run = function (args) {
        return this.octokit
            .users
            .getAuthenticated({})
            .then(function (res) {
            return {
                name: res.data.name,
                url: res.data.html_url,
                email: res.data.email,
                followers: res.data.followers,
                public_repos: res.data.public_repos,
                private_repos: res.data.total_private_repos
            };
        });
    };
    return GitHubCommand;
}(types_1.AsyncCommand));
exports.GitHubCommand = GitHubCommand;
var GitHubReposSubCommand = /** @class */ (function (_super) {
    __extends(GitHubReposSubCommand, _super);
    function GitHubReposSubCommand(octokit) {
        var _this = _super.call(this) || this;
        _this.name = 'github';
        _this.description = 'shows GitHub owned repositories';
        _this.subCommands = {};
        _this.octokit = octokit;
        _this.helpTopic = new helpTopic_1.HelpTopic(_this, {
            synopsis: 'github repos [-l]',
            options: {
                '-l': 'List all repos written in a specified language'
            },
            examples: [
                {
                    cmd: 'github repos -l C++',
                    description: 'The following command shows all owned GitHub repos written in C++ language'
                }
            ]
        });
        return _this;
    }
    GitHubReposSubCommand.prototype.run = function (args) {
        return this.octokit
            .repos
            .list({ sort: 'updated' })
            .then(function (res) {
            var data = res.data.map(function (repo) { return ({
                name: repo.full_name,
                language: repo.language || 'undefined',
                stars: repo.stargazers_count,
                forks: repo.forks_count,
                last_updated: repo.updated_at
            }); });
            if (args.l) {
                data = data.filter(function (i) { return i.language.indexOf(args.l) >= 0; });
            }
            return data;
        });
    };
    return GitHubReposSubCommand;
}(types_1.AsyncCommand));
//# sourceMappingURL=GitHubCommand.js.map